@@ -17,6 +17,7 @@ class GeneticOptimization(BaseOptimizationAlgorithm):
                  elitism=2,
                  mutation_rate=0.05,
                  minimize=True,
+                 logger=None,
                  **kwargs):
         """
         Parameters
@@ -46,6 +47,9 @@ class GeneticOptimization(BaseOptimizationAlgorithm):
         minimize : bool, default=True
             Defines if the objective value is to be maximized or minimized
 
+        logger: Logger or None, optional (default=None)
+            - accepts `logging.Logger` instance.
+            
         **kwargs
             Any extra keyword argument for objective_function
 
@@ -54,7 +58,7 @@ class GeneticOptimization(BaseOptimizationAlgorithm):
         best_feature_list : ndarray of shape (n_features)
             list of features with the best result of the entire run
         """
-        super().__init__(objective_function, n_iteration, timeout, population_size, minimize, **kwargs)
+        super().__init__(objective_function, n_iteration, timeout, population_size, minimize, logger, **kwargs)
         self.n_generations = n_iteration
         self.selective_pressure = selective_pressure
         self.elitism = elitism
